Merge "Wifi usability: Change the unit of the threshold for tx/rx throughput from Mbps to Kbps" into qt-qpr1-dev
am: a295feab37

Change-Id: Ib759afbf288649cea7f2f4ca39bfef8eb88fc17c
diff --git a/proto/src/wifi.proto b/proto/src/wifi.proto
index 353a187..fbf6ca5 100644
--- a/proto/src/wifi.proto
+++ b/proto/src/wifi.proto
@@ -1798,12 +1798,12 @@
   optional int32 data_stall_duration_ms = 5;
 
   // Threshold of Tx throughput below which to trigger a data stall
-  // measured in Mbps
-  optional int32 data_stall_tx_tput_thr_mbps = 6;
+  // measured in Kbps
+  optional int32 data_stall_tx_tput_thr_kbps = 6;
 
   // Threshold of Rx throughput below which to trigger a data stall
-  // measured in Mbps
-  optional int32 data_stall_rx_tput_thr_mbps = 7;
+  // measured in Kbps
+  optional int32 data_stall_rx_tput_thr_kbps = 7;
 
   // Threshold of Tx packet error rate above which to trigger a data stall
   // in percentage